@@ -1,9 +1,13 @@
 package MojoMojo::Formatter::Textile;
 
+use base qw/MojoMojo::Formatter/;
+
 use Text::Textile2;
 use Text::SmartyPants;
 my $textile = Text::Textile2->new(flavor=>"xhtml1",charset=>'utf-8');
 
+sub primary_formatter { 1; }
+
 =head1 NAME
 
 MojoMojo::Formatter::Textile - Texile formatting for your content
@@ -36,6 +40,7 @@ context object.
 sub format_content {
     my ($class,$content,$c)=@_;
     # Let textile handle the rest
+    return unless $c->pref('main_formatter') eq 'MojoMojo::Formatter::Textile' || ! $c->pref('main_formatter');
     $$content= $textile->process( $$content );
     $$content= Text::SmartyPants->process( $$content );
 }
