@@ -9,11 +9,11 @@
 use strict;
 use FindBin;
 use lib "$FindBin::Bin/../lib";
-use MojoMojo::Search::Plucene;
+use MojoMojo::Model::Search::Plucene;
 use Data::Dumper;
 
 my $index = "$FindBin::Bin/../plucene";
-my $p = MojoMojo::Search::Plucene->open($index) or die "Unable to open index $index";
+my $p = MojoMojo::Model::Search::Plucene->open($index) or die "Unable to open index $index";
 
 my $query = shift;
 if ($query) {
